from distutils.core import setup

setup(
	name		= 'gilson_nester',
	version		= '1.1.0',
	py_modules	= ['gilson_nester'],
	author		= 'Gilson',
	author_email	= 'gilson10@gmail.com',
	url		= 'https://github.com/oliveiragil',
	description	= 'A simple printer for  nested lists - HF Python',
)
